@@ -71,18 +71,20 @@ class GaussianProcessRegressor:
             "Matern": 1.0
             * Matern(length_scale=1.0, length_scale_bounds=(1e-1, 10.0), nu=2.5),
         }
-        self.selectedKernels = [defaultKernels[kernel] for kernel in self.kernels]
+        self.selectedKernels = {
+            kernel: defaultKernels[kernel] for kernel in self.kernels
+        }
 
     def addKernel(self, kernel: Kernel):
         """
         Add a Gaussian Process kernel from scikit-learn. Use this method
         to add combined kernels from WhiteKernel, Sum & Product.
         """
-        self.selectedKernels.append(kernel)
+        self.selectedKernels[kernel.__class__.__name__] = kernel
 
-    def load(self, currentKernel: Kernel):
+    def load(self, currentKernel: Kernel, **kwargs):
         """
-        Initialize a new GaussianProcessRegressor with the given kernel.
+        Initialize a new GaussianProcessRegressor with the given kernel & keyword arguments.
         """
         return ScikitGaussianProcessRegressor(
             kernel=currentKernel,
@@ -93,6 +95,7 @@ class GaussianProcessRegressor:
             copy_X_train=True,
             random_state=self.randomState,
             noise=self.noise,
+            **kwargs,
         )
 
 
@@ -123,12 +126,16 @@ class RegressorCollection:
             kwargs = getattr(self, regressor)
             # enumerate GaussianProcessRegressors if selected with different kernels
             if regressor == "GaussianProcess":
+                gaussianRegressor = GaussianProcessRegressor(**kwargs)
                 if kwargs != None:
-                    gaussianRegressors = regressors[regressor].set_params(**kwargs)
-                else:
-                    continue
-                for kernel in gaussianRegressors.selectedKernels:
-                    self.selectedRegressors.append(gaussianRegressors.load(kernel))
+                    for name, kernel in gaussianRegressor.selectedKernels.items():
+                        gaussianWithKernel = gaussianRegressor.load(kernel, **kwargs)
+                        gaussianWithKernel.__class__.__name__ = (
+                            f"{gaussianRegressor.__class__.__name__}Kernel{name}"
+                        )
+                        self.selectedRegressors.append(gaussianWithKernel)
+                    else:
+                        continue
             elif kwargs == "default":
                 self.selectedRegressors.append(regressors[regressor])
             elif kwargs != None:
@@ -162,7 +169,7 @@ class BayesianOptimizer:
         model,
         hyperparameterSpaces: Iterable[Space],
         inputData,
-        trainingLabels,
+        inputLabels,
         objectiveToMinimize: Callable,
         pointSampleCount: int = cpu_count(),
         pointSampleStrategy="cl_min",
@@ -181,15 +188,15 @@ class BayesianOptimizer:
         for regressor in self.regressorCollection.selectedRegressors:
             for sampleIteration in range(downsampleCount):
                 sampler = np.random.RandomState(randomSeed * sampleIteration)
-                lowestClassCount = np.min(np.bincount(trainingLabels))
+                lowestClassCount = np.min(np.bincount(inputLabels))
                 balancedLabelMask = np.hstack(
                     [
                         sampler.choice(
-                            np.where(trainingLabels == label)[0],
+                            np.where(inputLabels == label)[0],
                             lowestClassCount,
                             replace=False,
                         )
-                        for label in np.unique(trainingLabels)
+                        for label in np.unique(inputLabels)
                     ]
                 )
                 balancedData = (
@@ -197,13 +204,13 @@ class BayesianOptimizer:
                     if not isinstance(inputData, DataFrame)
                     else inputData.iloc[balancedLabelMask]
                 )
-                balancedLabels = trainingLabels[balancedLabelMask]
+                balancedLabels = inputLabels[balancedLabelMask]
                 loadedObjective = partial(
                     objectiveToMinimize,
                     **{
                         "model": model,
                         "inputData": balancedData,
-                        "trainingLabels": balancedLabels,
+                        "inputLabels": balancedLabels,
                     },
                 )
                 regressorName = regressor.__class__.__name__ + (
@@ -258,7 +265,7 @@ class BayesianOptimizer:
                     optimizedResult = optimizer.get_result()
                     if self.verbose:
                         print(
-                            f"Finished iteration {i+1} of {self.iterations} optimizing {model.__class__.__name__} with {regressorName}. Best score: {bestScore}",
+                            f"Input data downsample {sampleIteration+1} / {downsampleCount}: Finished iteration {i+1} of {self.iterations} optimizing {model.__class__.__name__} with {regressorName}. Best score: {bestScore}",
                             end="\r",
                         )
 
